@@ -28,6 +28,12 @@ def hhmmss_to_seconds(ts):
             for i, x in enumerate(reversed(ts.split(':'))))
 
 
+def get_video_aspect_ratio(video_path):
+    w, h = get_video_size(video_path)
+    gcd = math.gcd(w, h)
+    return w // gcd, h // gcd
+
+
 def get_video_duration(video_path):
     video_path = str(video_path)
     if not osp.exists(video_path):
